@@ -30,7 +30,7 @@ class Config:
                 self.steps[step_name] = SetupConfig(**step)
             else:
                 self.steps[step_name] = StepConfig.from_dict(step)
-                self.steps[step_name].add_shared_env(self.shared_envs)
+                self.steps[step_name].add_shared_env(self.shared_envs)  # type: ignore
 
         self.add_other_steps(lume_dict)
 
